##
##  ansible.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  2.17.4
%define       V_dist  2.17.4

#   package information
Name:         ansible
Summary:      IT Automation Tool
URL:          https://www.ansible.com/
Vendor:       Michael DeHaan
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        SCM
License:      GPL
Version:      %{V_opkg}
Release:      20240926

#   list of sources
Source0:      https://github.com/ansible/ansible/archive/v%{V_dist}.tar.gz
Source1:      ansible.cfg
Source2:      hosts

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  python, python-net, python-text, python-yaml, python-setup, python-crypto
PreReq:       python, python-net, python-text, python-yaml, python-setup, python-crypto

%description
    Ansible is a radically simple IT automation system. It handles
    configuration-management, application deployment, cloud
    provisioning, ad-hoc task-execution, and multinode orchestration -
    including trivializing things like zero downtime rolling updates
    with load balancers.

%track
    prog ansible = {
        version   = %{V_dist}
        url       = https://github.com/ansible/ansible/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n ansible-%{V_dist}

%build
    #   adjust paths
    %{l_shtool} subst \
        -e 's;/etc/ansible/ansible\.cfg;%{l_prefix}/etc/ansible/ansible.cfg;' \
        lib/ansible/config/manager.py
    %{l_shtool} subst \
        -e 's;/etc/ansible/hosts;%{l_prefix}/etc/ansible/hosts;' \
        lib/ansible/config/base.yml \
        lib/ansible/inventory/manager.py

%install
    #   install program
    ANSIBLE_SKIP_CONFLICT_CHECK=1 \
    %{l_prefix}/bin/python setup.py install \
        --root=$RPM_BUILD_ROOT \
        --prefix=%{l_prefix}

    #   install default global configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/ansible
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE ansible.cfg} $RPM_BUILD_ROOT%{l_prefix}/etc/ansible/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE hosts} $RPM_BUILD_ROOT%{l_prefix}/etc/ansible/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

